# ShipMMG: Ship Maneuvering Simulation Model

![codecov](https://github.com/ShipMMG/shipmmg/workflows/codecov/badge.svg)
[![codecov](https://codecov.io/gh/ShipMMG/shipmmg/branch/main/graph/badge.svg?token=VQ1J2RTC7X)](https://codecov.io/gh/ShipMMG/shipmmg)

## What is it?

**ShipMMG** is a unofficial Python package of ship maneuvering simulation with respect to the research committee on “standardization of mathematical model for ship maneuvering predictions” was organized by the JASNAOE.

## Where to get it
The source code is currently hosted on GitHub at: [https://github.com/ShipMMG/shipmmg](https://github.com/ShipMMG/shipmmg)

Binary installers for the latest released version will be available at the Python package index. Now, please install pDESy as following.

```sh
pip install shipmmg
# pip install git+ssh://git@github.com/ShipMMG/shipmmg.git # Install from GitHub
```

## License
[MIT](https://github.com/ShipMMG/shipmmg/blob/master/LICENSE)

## Contribution
1. Fork it ( http://github.com/ShipMMG/shipmmg/fork )
2. Create your feature branch (git checkout -b my-new-feature)
3. Commit your changes (git commit -am 'Add some feature')
4. Push to the branch (git push origin my-new-feature)
5. Create new Pull Request

If you want to join this project as a researcher, please contact [me](https://github.com/taiga4112).